[nautilus-actions] NAIFactoryProvider interface is renamed to FMAIFactoryProvider
- From: Pierre Wieser <pwieser src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [nautilus-actions] NAIFactoryProvider interface is renamed to FMAIFactoryProvider
- Date: Wed, 15 Feb 2017 22:46:25 +0000 (UTC)
commit fbccfa273c0e891ce839ca42e9c009a448cd5d28
Author: Pierre Wieser <pwieser trychlos org>
Date: Mon Sep 7 22:37:54 2015 +0200
NAIFactoryProvider interface is renamed to FMAIFactoryProvider
src/api/Makefile.am | 4 +-
src/api/fma-data-types.h | 2 +-
src/api/fma-ifactory-object.h | 10 +-
...provider.h => fma-ifactory-provider-provider.h} | 8 +-
...ifactory-provider.h => fma-ifactory-provider.h} | 80 +++++++++---------
src/api/na-iio-provider.h | 2 +-
src/core/Makefile.am | 2 +-
...ifactory-provider.c => fma-ifactory-provider.c} | 92 ++++++++++----------
src/core/na-factory-object.c | 38 ++++----
src/core/na-factory-object.h | 6 +-
src/core/na-factory-provider.c | 20 ++--
src/core/na-factory-provider.h | 10 +-
src/core/na-object-action.c | 18 ++--
src/core/na-object-item.c | 2 +-
src/core/na-object-menu.c | 12 ++--
src/core/na-object-profile.c | 8 +-
src/io-desktop/nadp-desktop-provider.c | 12 ++--
src/io-desktop/nadp-reader.c | 40 ++++----
src/io-desktop/nadp-reader.h | 8 +-
src/io-desktop/nadp-writer.c | 16 ++--
src/io-desktop/nadp-writer.h | 8 +-
src/io-gconf/nagp-gconf-provider.c | 12 ++--
src/io-gconf/nagp-reader.c | 38 ++++----
src/io-gconf/nagp-reader.h | 8 +-
src/io-gconf/nagp-writer.c | 10 +-
src/io-gconf/nagp-writer.h | 10 +-
src/io-xml/naxml-provider.c | 12 ++--
src/io-xml/naxml-reader.c | 24 +++---
src/io-xml/naxml-reader.h | 8 +-
src/io-xml/naxml-writer.c | 12 ++--
src/io-xml/naxml-writer.h | 8 +-
31 files changed, 270 insertions(+), 270 deletions(-)
---
diff --git a/src/api/Makefile.am b/src/api/Makefile.am
index a36def2..5c71ea6 100644
--- a/src/api/Makefile.am
+++ b/src/api/Makefile.am
@@ -33,8 +33,8 @@ api_include_HEADERS = \
fma-dbus.h \
fma-iexporter.h \
na-iimporter.h \
- na-ifactory-provider.h \
- na-ifactory-provider-provider.h \
+ fma-ifactory-provider.h \
+ fma-ifactory-provider-provider.h \
na-iio-provider.h \
\
fma-boxed.h \
diff --git a/src/api/fma-data-types.h b/src/api/fma-data-types.h
index c9b654e..21e9eaa 100644
--- a/src/api/fma-data-types.h
+++ b/src/api/fma-data-types.h
@@ -56,7 +56,7 @@ G_BEGIN_DECLS
* Each elementary data which would take advantage of #FMABoxed
* facilities should be typed at instanciation time.
*
- * #NAIFactoryProvider implementations should provide a primitive for
+ * #FMAIFactoryProvider implementations should provide a primitive for
* reading (resp. writing) a value for each of these elementary data
* types.
*
diff --git a/src/api/fma-ifactory-object.h b/src/api/fma-ifactory-object.h
index 7751a14..64c88ba 100644
--- a/src/api/fma-ifactory-object.h
+++ b/src/api/fma-ifactory-object.h
@@ -78,7 +78,7 @@
#include "fma-data-def.h"
#include "fma-data-boxed.h"
-#include "na-ifactory-provider-provider.h"
+#include "fma-ifactory-provider-provider.h"
G_BEGIN_DECLS
@@ -186,7 +186,7 @@ typedef struct {
*
* Since: 2.30
*/
- void ( *read_start ) ( FMAIFactoryObject *instance, const NAIFactoryProvider *reader, void
*reader_data, GSList **messages );
+ void ( *read_start ) ( FMAIFactoryObject *instance, const FMAIFactoryProvider *reader, void
*reader_data, GSList **messages );
/**
* read_done:
@@ -200,7 +200,7 @@ typedef struct {
*
* Since: 2.30
*/
- void ( *read_done ) ( FMAIFactoryObject *instance, const NAIFactoryProvider *reader, void
*reader_data, GSList **messages );
+ void ( *read_done ) ( FMAIFactoryObject *instance, const FMAIFactoryProvider *reader, void
*reader_data, GSList **messages );
/**
* write_start:
@@ -216,7 +216,7 @@ typedef struct {
*
* Since: 2.30
*/
- guint ( *write_start )( FMAIFactoryObject *instance, const NAIFactoryProvider *writer, void
*writer_data, GSList **messages );
+ guint ( *write_start )( FMAIFactoryObject *instance, const FMAIFactoryProvider *writer, void
*writer_data, GSList **messages );
/**
* write_done:
@@ -232,7 +232,7 @@ typedef struct {
*
* Since: 2.30
*/
- guint ( *write_done ) ( FMAIFactoryObject *instance, const NAIFactoryProvider *writer, void
*writer_data, GSList **messages );
+ guint ( *write_done ) ( FMAIFactoryObject *instance, const FMAIFactoryProvider *writer, void
*writer_data, GSList **messages );
}
FMAIFactoryObjectInterface;
diff --git a/src/api/na-ifactory-provider-provider.h b/src/api/fma-ifactory-provider-provider.h
similarity index 80%
rename from src/api/na-ifactory-provider-provider.h
rename to src/api/fma-ifactory-provider-provider.h
index 2f78f97..cb031da 100644
--- a/src/api/na-ifactory-provider-provider.h
+++ b/src/api/fma-ifactory-provider-provider.h
@@ -27,15 +27,15 @@
* ... and many others (see AUTHORS)
*/
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_IFACTORY_PROVIDER_PROVIDER_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_IFACTORY_PROVIDER_PROVIDER_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_IFACTORY_PROVIDER_PROVIDER_H__
+#define __FILE_MANAGER_ACTIONS_API_IFACTORY_PROVIDER_PROVIDER_H__
#include <glib.h>
G_BEGIN_DECLS
-typedef struct _NAIFactoryProvider NAIFactoryProvider;
+typedef struct _FMAIFactoryProvider FMAIFactoryProvider;
G_END_DECLS
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_IFACTORY_PROVIDER_PROVIDER_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_IFACTORY_PROVIDER_PROVIDER_H__ */
diff --git a/src/api/na-iio-provider.h b/src/api/na-iio-provider.h
index 83c39d9..f8c42c6 100644
--- a/src/api/na-iio-provider.h
+++ b/src/api/na-iio-provider.h
@@ -101,7 +101,7 @@
*
* These services may be fully implemented by the I/O provider itself.
* Or, the I/O provider may also prefer to take advantage of the data
- * factory management (see #FMAIFactoryObject and #NAIFactoryProvider
+ * factory management (see #FMAIFactoryObject and #FMAIFactoryProvider
* interfaces) services.
*
* <refsect2>
diff --git a/src/core/Makefile.am b/src/core/Makefile.am
index a3b0a1e..bf5387d 100644
--- a/src/core/Makefile.am
+++ b/src/core/Makefile.am
@@ -81,7 +81,7 @@ libna_core_la_SOURCES = \
fma-iduplicable.c \
fma-iexporter.c \
fma-ifactory-object.c \
- na-ifactory-provider.c \
+ fma-ifactory-provider.c \
na-iimporter.c \
na-iio-provider.c \
na-import-mode.c \
diff --git a/src/core/na-factory-object.h b/src/core/na-factory-object.h
index 9141922..794412d 100644
--- a/src/core/na-factory-object.h
+++ b/src/core/na-factory-object.h
@@ -38,7 +38,7 @@
* published as API.
*/
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
G_BEGIN_DECLS
@@ -62,8 +62,8 @@ gboolean na_factory_object_is_valid ( const FMAIFactoryObject *objec
void na_factory_object_dump ( const FMAIFactoryObject *object );
void na_factory_object_finalize ( FMAIFactoryObject *object );
-void na_factory_object_read_item ( FMAIFactoryObject *object, const NAIFactoryProvider
*reader, void *reader_data, GSList **messages );
-guint na_factory_object_write_item ( FMAIFactoryObject *object, const NAIFactoryProvider
*writer, void *writer_data, GSList **messages );
+void na_factory_object_read_item ( FMAIFactoryObject *object, const FMAIFactoryProvider
*reader, void *reader_data, GSList **messages );
+guint na_factory_object_write_item ( FMAIFactoryObject *object, const FMAIFactoryProvider
*writer, void *writer_data, GSList **messages );
void *na_factory_object_get_as_void ( const FMAIFactoryObject *object, const gchar *name );
void na_factory_object_get_as_value ( const FMAIFactoryObject *object, const gchar *name, GValue
*value );
diff --git a/src/core/na-object-action.c b/src/core/na-object-action.c
index cd76660..17b71d6 100644
--- a/src/core/na-object-action.c
+++ b/src/core/na-object-action.c
@@ -78,9 +78,9 @@ static gboolean object_is_valid( const NAObject *object );
static void ifactory_object_iface_init( FMAIFactoryObjectInterface *iface, void *user_data );
static guint ifactory_object_get_version( const FMAIFactoryObject *instance );
static FMADataGroup *ifactory_object_get_groups( const FMAIFactoryObject *instance );
-static void ifactory_object_read_done( FMAIFactoryObject *instance, const NAIFactoryProvider
*reader, void *reader_data, GSList **messages );
-static guint ifactory_object_write_start( FMAIFactoryObject *instance, const NAIFactoryProvider
*writer, void *writer_data, GSList **messages );
-static guint ifactory_object_write_done( FMAIFactoryObject *instance, const NAIFactoryProvider
*writer, void *writer_data, GSList **messages );
+static void ifactory_object_read_done( FMAIFactoryObject *instance, const FMAIFactoryProvider
*reader, void *reader_data, GSList **messages );
+static guint ifactory_object_write_start( FMAIFactoryObject *instance, const FMAIFactoryProvider
*writer, void *writer_data, GSList **messages );
+static guint ifactory_object_write_done( FMAIFactoryObject *instance, const FMAIFactoryProvider
*writer, void *writer_data, GSList **messages );
static void icontext_iface_init( FMAIContextInterface *iface, void *user_data );
static gboolean icontext_is_candidate( FMAIContext *object, guint target, GList *selection );
@@ -88,7 +88,7 @@ static gboolean icontext_is_candidate( FMAIContext *object, guint target, GL
static NAObjectProfile *read_done_convert_v1_to_v2( FMAIFactoryObject *instance );
static void read_done_deals_with_toolbar_label( FMAIFactoryObject *instance );
-static guint write_done_write_profiles( FMAIFactoryObject *instance, const NAIFactoryProvider
*writer, void *writer_data, GSList **messages );
+static guint write_done_write_profiles( FMAIFactoryObject *instance, const FMAIFactoryProvider
*writer, void *writer_data, GSList **messages );
static gboolean is_valid_label( const NAObjectAction *action );
static gboolean is_valid_toolbar_label( const NAObjectAction *action );
@@ -381,7 +381,7 @@ ifactory_object_get_groups( const FMAIFactoryObject *instance )
* action-specific properties (not to check for profiles consistency)
*/
static void
-ifactory_object_read_done( FMAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data,
GSList **messages )
+ifactory_object_read_done( FMAIFactoryObject *instance, const FMAIFactoryProvider *reader, void
*reader_data, GSList **messages )
{
guint iversion;
NAObjectProfile *profile;
@@ -414,7 +414,7 @@ ifactory_object_read_done( FMAIFactoryObject *instance, const NAIFactoryProvider
}
static guint
-ifactory_object_write_start( FMAIFactoryObject *instance, const NAIFactoryProvider *writer, void
*writer_data, GSList **messages )
+ifactory_object_write_start( FMAIFactoryObject *instance, const FMAIFactoryProvider *writer, void
*writer_data, GSList **messages )
{
na_object_item_rebuild_children_slist( NA_OBJECT_ITEM( instance ));
@@ -422,7 +422,7 @@ ifactory_object_write_start( FMAIFactoryObject *instance, const NAIFactoryProvid
}
static guint
-ifactory_object_write_done( FMAIFactoryObject *instance, const NAIFactoryProvider *writer, void
*writer_data, GSList **messages )
+ifactory_object_write_done( FMAIFactoryObject *instance, const FMAIFactoryProvider *writer, void
*writer_data, GSList **messages )
{
guint code;
@@ -531,7 +531,7 @@ read_done_deals_with_toolbar_label( FMAIFactoryObject *instance )
* note that subitems string list has been rebuilt on write_start
*/
static guint
-write_done_write_profiles( FMAIFactoryObject *instance, const NAIFactoryProvider *writer, void *writer_data,
GSList **messages )
+write_done_write_profiles( FMAIFactoryObject *instance, const FMAIFactoryProvider *writer, void
*writer_data, GSList **messages )
{
static const gchar *thisfn = "na_object_action_write_done_write_profiles";
guint code;
@@ -545,7 +545,7 @@ write_done_write_profiles( FMAIFactoryObject *instance, const NAIFactoryProvider
profile = NA_OBJECT_PROFILE( na_object_get_item( instance, ic->data ));
if( profile ){
- code = na_ifactory_provider_write_item( writer, writer_data, FMA_IFACTORY_OBJECT(
profile ), messages );
+ code = fma_ifactory_provider_write_item( writer, writer_data, FMA_IFACTORY_OBJECT(
profile ), messages );
} else {
g_warning( "%s: profile not found: %s", thisfn, ( const gchar * ) ic->data );
diff --git a/src/core/na-object-item.c b/src/core/na-object-item.c
index c35554d..bfc03b2 100644
--- a/src/core/na-object-item.c
+++ b/src/core/na-object-item.c
@@ -758,7 +758,7 @@ na_object_item_free_items( GList *items )
* na_object_item_deals_with_version:
* @item: this #NAObjectItem -derived object.
*
- * Just after the @item has been read from NAIFactoryProvider, setup
+ * Just after the @item has been read from FMAIFactoryProvider, setup
* the version. This is needed because some conversions may occur in
* this object.
*
diff --git a/src/core/na-object-menu.c b/src/core/na-object-menu.c
index 142abc5..cdb749b 100644
--- a/src/core/na-object-menu.c
+++ b/src/core/na-object-menu.c
@@ -73,9 +73,9 @@ static void object_dump( const NAObject *object );
static void ifactory_object_iface_init( FMAIFactoryObjectInterface *iface, void *user_data );
static guint ifactory_object_get_version( const FMAIFactoryObject *instance );
static FMADataGroup *ifactory_object_get_groups( const FMAIFactoryObject *instance );
-static void ifactory_object_read_done( FMAIFactoryObject *instance, const NAIFactoryProvider
*reader, void *reader_data, GSList **messages );
-static guint ifactory_object_write_start( FMAIFactoryObject *instance, const NAIFactoryProvider
*writer, void *writer_data, GSList **messages );
-static guint ifactory_object_write_done( FMAIFactoryObject *instance, const NAIFactoryProvider
*writer, void *writer_data, GSList **messages );
+static void ifactory_object_read_done( FMAIFactoryObject *instance, const FMAIFactoryProvider
*reader, void *reader_data, GSList **messages );
+static guint ifactory_object_write_start( FMAIFactoryObject *instance, const FMAIFactoryProvider
*writer, void *writer_data, GSList **messages );
+static guint ifactory_object_write_done( FMAIFactoryObject *instance, const FMAIFactoryProvider
*writer, void *writer_data, GSList **messages );
static void icontext_iface_init( FMAIContextInterface *iface, void *user_data );
static gboolean icontext_is_candidate( FMAIContext *object, guint target, GList *selection );
@@ -292,7 +292,7 @@ ifactory_object_get_groups( const FMAIFactoryObject *instance )
}
static void
-ifactory_object_read_done( FMAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data,
GSList **messages )
+ifactory_object_read_done( FMAIFactoryObject *instance, const FMAIFactoryProvider *reader, void
*reader_data, GSList **messages )
{
g_debug( "na_object_menu_ifactory_object_read_done: instance=%p", ( void * ) instance );
@@ -308,7 +308,7 @@ ifactory_object_read_done( FMAIFactoryObject *instance, const NAIFactoryProvider
}
static guint
-ifactory_object_write_start( FMAIFactoryObject *instance, const NAIFactoryProvider *writer, void
*writer_data, GSList **messages )
+ifactory_object_write_start( FMAIFactoryObject *instance, const FMAIFactoryProvider *writer, void
*writer_data, GSList **messages )
{
na_object_item_rebuild_children_slist( NA_OBJECT_ITEM( instance ));
@@ -316,7 +316,7 @@ ifactory_object_write_start( FMAIFactoryObject *instance, const NAIFactoryProvid
}
static guint
-ifactory_object_write_done( FMAIFactoryObject *instance, const NAIFactoryProvider *writer, void
*writer_data, GSList **messages )
+ifactory_object_write_done( FMAIFactoryObject *instance, const FMAIFactoryProvider *writer, void
*writer_data, GSList **messages )
{
return( NA_IIO_PROVIDER_CODE_OK );
}
diff --git a/src/core/na-object-profile.c b/src/core/na-object-profile.c
index 67f3a99..1e31048 100644
--- a/src/core/na-object-profile.c
+++ b/src/core/na-object-profile.c
@@ -82,8 +82,8 @@ static gboolean object_is_valid( const NAObject *object );
static void ifactory_object_iface_init( FMAIFactoryObjectInterface *iface, void *user_data );
static guint ifactory_object_get_version( const FMAIFactoryObject *instance );
static FMADataGroup *ifactory_object_get_groups( const FMAIFactoryObject *instance );
-static void ifactory_object_read_done( FMAIFactoryObject *instance, const NAIFactoryProvider
*reader, void *reader_data, GSList **messages );
-static guint ifactory_object_write_done( FMAIFactoryObject *instance, const NAIFactoryProvider
*writer, void *writer_data, GSList **messages );
+static void ifactory_object_read_done( FMAIFactoryObject *instance, const FMAIFactoryProvider
*reader, void *reader_data, GSList **messages );
+static guint ifactory_object_write_done( FMAIFactoryObject *instance, const FMAIFactoryProvider
*writer, void *writer_data, GSList **messages );
static void icontext_iface_init( FMAIContextInterface *iface, void *user_data );
static gboolean icontext_is_candidate( FMAIContext *object, guint target, GList *selection );
@@ -341,7 +341,7 @@ ifactory_object_get_groups( const FMAIFactoryObject *instance )
}
static void
-ifactory_object_read_done( FMAIFactoryObject *instance, const NAIFactoryProvider *reader, void *reader_data,
GSList **messages )
+ifactory_object_read_done( FMAIFactoryObject *instance, const FMAIFactoryProvider *reader, void
*reader_data, GSList **messages )
{
static const gchar *thisfn = "na_object_profile_ifactory_object_read_done";
NAObjectAction *action;
@@ -366,7 +366,7 @@ ifactory_object_read_done( FMAIFactoryObject *instance, const NAIFactoryProvider
}
static guint
-ifactory_object_write_done( FMAIFactoryObject *instance, const NAIFactoryProvider *writer, void
*writer_data, GSList **messages )
+ifactory_object_write_done( FMAIFactoryObject *instance, const FMAIFactoryProvider *writer, void
*writer_data, GSList **messages )
{
return( NA_IIO_PROVIDER_CODE_OK );
}
diff --git a/src/io-desktop/nadp-desktop-provider.c b/src/io-desktop/nadp-desktop-provider.c
index 0b9ffe6..9448ad4 100644
--- a/src/io-desktop/nadp-desktop-provider.c
+++ b/src/io-desktop/nadp-desktop-provider.c
@@ -35,7 +35,7 @@
#include <string.h>
#include <api/fma-core-utils.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include "nadp-desktop-provider.h"
#include "nadp-formats.h"
@@ -64,8 +64,8 @@ static gchar *iio_provider_get_id( const NAIIOProvider *provider );
static gchar *iio_provider_get_name( const NAIIOProvider *provider );
static guint iio_provider_get_version( const NAIIOProvider *provider );
-static void ifactory_provider_iface_init( NAIFactoryProviderInterface *iface );
-static guint ifactory_provider_get_version( const NAIFactoryProvider *reader );
+static void ifactory_provider_iface_init( FMAIFactoryProviderInterface *iface );
+static guint ifactory_provider_get_version( const FMAIFactoryProvider *reader );
static void iimporter_iface_init( NAIImporterInterface *iface );
static guint iimporter_get_version( const NAIImporter *importer );
@@ -131,7 +131,7 @@ nadp_desktop_provider_register_type( GTypeModule *module )
g_type_module_add_interface( module, st_module_type, NA_TYPE_IIO_PROVIDER, &iio_provider_iface_info );
- g_type_module_add_interface( module, st_module_type, NA_TYPE_IFACTORY_PROVIDER,
&ifactory_provider_iface_info );
+ g_type_module_add_interface( module, st_module_type, FMA_TYPE_IFACTORY_PROVIDER,
&ifactory_provider_iface_info );
g_type_module_add_interface( module, st_module_type, NA_TYPE_IIMPORTER, &iimporter_iface_info );
@@ -260,7 +260,7 @@ iio_provider_get_name( const NAIIOProvider *provider )
}
static void
-ifactory_provider_iface_init( NAIFactoryProviderInterface *iface )
+ifactory_provider_iface_init( FMAIFactoryProviderInterface *iface )
{
static const gchar *thisfn = "nadp_desktop_provider_ifactory_provider_iface_init";
@@ -276,7 +276,7 @@ ifactory_provider_iface_init( NAIFactoryProviderInterface *iface )
}
static guint
-ifactory_provider_get_version( const NAIFactoryProvider *reader )
+ifactory_provider_get_version( const FMAIFactoryProvider *reader )
{
return( 1 );
}
diff --git a/src/io-desktop/nadp-reader.c b/src/io-desktop/nadp-reader.c
index 8de10c3..835de12 100644
--- a/src/io-desktop/nadp-reader.c
+++ b/src/io-desktop/nadp-reader.c
@@ -38,7 +38,7 @@
#include <api/fma-core-utils.h>
#include <api/fma-data-types.h>
#include <api/fma-ifactory-object-data.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include <api/na-object-api.h>
#include "nadp-desktop-provider.h"
@@ -72,12 +72,12 @@ static FMAIFactoryObject *item_from_desktop_file( const NadpDesktopProvider *pro
static void desktop_weak_notify( NadpDesktopFile *ndf, GObject *item );
static void free_desktop_paths( GList *paths );
-static void read_start_read_subitems_key( const NAIFactoryProvider *provider, NAObjectItem
*item, NadpReaderData *reader_data, GSList **messages );
-static void read_start_profile_attach_profile( const NAIFactoryProvider *provider,
NAObjectProfile *profile, NadpReaderData *reader_data, GSList **messages );
+static void read_start_read_subitems_key( const FMAIFactoryProvider *provider, NAObjectItem
*item, NadpReaderData *reader_data, GSList **messages );
+static void read_start_profile_attach_profile( const FMAIFactoryProvider *provider,
NAObjectProfile *profile, NadpReaderData *reader_data, GSList **messages );
-static gboolean read_done_item_is_writable( const NAIFactoryProvider *provider, NAObjectItem *item,
NadpReaderData *reader_data, GSList **messages );
-static void read_done_action_read_profiles( const NAIFactoryProvider *provider, NAObjectAction
*action, NadpReaderData *data, GSList **messages );
-static void read_done_action_load_profile( const NAIFactoryProvider *provider, NadpReaderData
*reader_data, const gchar *profile_id, GSList **messages );
+static gboolean read_done_item_is_writable( const FMAIFactoryProvider *provider, NAObjectItem
*item, NadpReaderData *reader_data, GSList **messages );
+static void read_done_action_read_profiles( const FMAIFactoryProvider *provider, NAObjectAction
*action, NadpReaderData *data, GSList **messages );
+static void read_done_action_load_profile( const FMAIFactoryProvider *provider, NadpReaderData
*reader_data, const gchar *profile_id, GSList **messages );
/*
* Returns an unordered list of FMAIFactoryObject-derived objects
@@ -300,7 +300,7 @@ item_from_desktop_file( const NadpDesktopProvider *provider, NadpDesktopFile *nd
reader_data = g_new0( NadpReaderData, 1 );
reader_data->ndf = ndf;
- na_ifactory_provider_read_item( NA_IFACTORY_PROVIDER( provider ), reader_data, item, messages
);
+ fma_ifactory_provider_read_item( FMA_IFACTORY_PROVIDER( provider ), reader_data, item,
messages );
na_object_set_provider_data( item, ndf );
g_object_weak_ref( G_OBJECT( item ), ( GWeakNotify ) desktop_weak_notify, ndf );
@@ -419,11 +419,11 @@ nadp_reader_iimporter_import_from_uri( const NAIImporter *instance, void *parms_
* depending of the exact class of the NAObjectItem
*/
void
-nadp_reader_ifactory_provider_read_start( const NAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *serializable, GSList **messages )
+nadp_reader_ifactory_provider_read_start( const FMAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *serializable, GSList **messages )
{
static const gchar *thisfn = "nadp_reader_ifactory_provider_read_start";
- g_return_if_fail( NA_IS_IFACTORY_PROVIDER( reader ));
+ g_return_if_fail( FMA_IS_IFACTORY_PROVIDER( reader ));
g_return_if_fail( NADP_IS_DESKTOP_PROVIDER( reader ));
g_return_if_fail( FMA_IS_IFACTORY_OBJECT( serializable ));
@@ -448,7 +448,7 @@ nadp_reader_ifactory_provider_read_start( const NAIFactoryProvider *reader, void
}
static void
-read_start_read_subitems_key( const NAIFactoryProvider *provider, NAObjectItem *item, NadpReaderData
*reader_data, GSList **messages )
+read_start_read_subitems_key( const FMAIFactoryProvider *provider, NAObjectItem *item, NadpReaderData
*reader_data, GSList **messages )
{
GSList *subitems;
gboolean key_found;
@@ -467,7 +467,7 @@ read_start_read_subitems_key( const NAIFactoryProvider *provider, NAObjectItem *
}
static void
-read_start_profile_attach_profile( const NAIFactoryProvider *provider, NAObjectProfile *profile,
NadpReaderData *reader_data, GSList **messages )
+read_start_profile_attach_profile( const FMAIFactoryProvider *provider, NAObjectProfile *profile,
NadpReaderData *reader_data, GSList **messages )
{
na_object_attach_profile( reader_data->action, profile );
}
@@ -483,7 +483,7 @@ read_start_profile_attach_profile( const NAIFactoryProvider *provider, NAObjectP
* letting the caller deal with default values
*/
FMADataBoxed *
-nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *object, const FMADataDef *def, GSList **messages )
+nadp_reader_ifactory_provider_read_data( const FMAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *object, const FMADataDef *def, GSList **messages )
{
static const gchar *thisfn = "nadp_reader_ifactory_provider_read_data";
FMADataBoxed *boxed;
@@ -496,7 +496,7 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
GSList *slist_value;
guint uint_value;
- g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( reader ), NULL );
+ g_return_val_if_fail( FMA_IS_IFACTORY_PROVIDER( reader ), NULL );
g_return_val_if_fail( NADP_IS_DESKTOP_PROVIDER( reader ), NULL );
g_return_val_if_fail( FMA_IS_IFACTORY_OBJECT( object ), NULL );
@@ -581,12 +581,12 @@ nadp_reader_ifactory_provider_read_data( const NAIFactoryProvider *reader, void
* called when each FMAIFactoryObject object has been read
*/
void
-nadp_reader_ifactory_provider_read_done( const NAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *serializable, GSList **messages )
+nadp_reader_ifactory_provider_read_done( const FMAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *serializable, GSList **messages )
{
static const gchar *thisfn = "nadp_reader_ifactory_provider_read_done";
gboolean writable;
- g_return_if_fail( NA_IS_IFACTORY_PROVIDER( reader ));
+ g_return_if_fail( FMA_IS_IFACTORY_PROVIDER( reader ));
g_return_if_fail( NADP_IS_DESKTOP_PROVIDER( reader ));
g_return_if_fail( FMA_IS_IFACTORY_OBJECT( serializable ));
@@ -613,7 +613,7 @@ nadp_reader_ifactory_provider_read_done( const NAIFactoryProvider *reader, void
}
static gboolean
-read_done_item_is_writable( const NAIFactoryProvider *provider, NAObjectItem *item, NadpReaderData
*reader_data, GSList **messages )
+read_done_item_is_writable( const FMAIFactoryProvider *provider, NAObjectItem *item, NadpReaderData
*reader_data, GSList **messages )
{
NadpDesktopFile *ndf;
gchar *uri;
@@ -636,7 +636,7 @@ read_done_item_is_writable( const NAIFactoryProvider *provider, NAObjectItem *it
* - ensure that there is at least one profile attached to the action
*/
static void
-read_done_action_read_profiles( const NAIFactoryProvider *provider, NAObjectAction *action, NadpReaderData
*reader_data, GSList **messages )
+read_done_action_read_profiles( const FMAIFactoryProvider *provider, NAObjectAction *action, NadpReaderData
*reader_data, GSList **messages )
{
static const gchar *thisfn = "nadp_reader_read_done_action_read_profiles";
GSList *order;
@@ -666,7 +666,7 @@ read_done_action_read_profiles( const NAIFactoryProvider *provider, NAObjectActi
}
static void
-read_done_action_load_profile( const NAIFactoryProvider *provider, NadpReaderData *reader_data, const gchar
*profile_id, GSList **messages )
+read_done_action_load_profile( const FMAIFactoryProvider *provider, NadpReaderData *reader_data, const gchar
*profile_id, GSList **messages )
{
static const gchar *thisfn = "nadp_reader_read_done_action_load_profile";
NAObjectProfile *profile;
@@ -677,8 +677,8 @@ read_done_action_load_profile( const NAIFactoryProvider *provider, NadpReaderDat
na_object_set_id( profile, profile_id );
if( nadp_desktop_file_has_profile( reader_data->ndf, profile_id )){
- na_ifactory_provider_read_item(
- NA_IFACTORY_PROVIDER( provider ),
+ fma_ifactory_provider_read_item(
+ FMA_IFACTORY_PROVIDER( provider ),
reader_data,
FMA_IFACTORY_OBJECT( profile ),
messages );
diff --git a/src/io-desktop/nadp-reader.h b/src/io-desktop/nadp-reader.h
index b969fe9..a4ccb18 100644
--- a/src/io-desktop/nadp-reader.h
+++ b/src/io-desktop/nadp-reader.h
@@ -32,7 +32,7 @@
#include <api/na-iio-provider.h>
#include <api/na-iimporter.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
G_BEGIN_DECLS
@@ -40,9 +40,9 @@ GList *nadp_iio_provider_read_items ( const NAIIOProvider *prov
guint nadp_reader_iimporter_import_from_uri ( const NAIImporter *instance, void *parms_ptr );
-void nadp_reader_ifactory_provider_read_start( const NAIFactoryProvider *reader, void *reader_data,
const FMAIFactoryObject *serializable, GSList **messages );
-FMADataBoxed *nadp_reader_ifactory_provider_read_data ( const NAIFactoryProvider *reader, void *reader_data,
const FMAIFactoryObject *serializable, const FMADataDef *iddef, GSList **messages );
-void nadp_reader_ifactory_provider_read_done ( const NAIFactoryProvider *reader, void *reader_data,
const FMAIFactoryObject *serializable, GSList **messages );
+void nadp_reader_ifactory_provider_read_start( const FMAIFactoryProvider *reader, void *reader_data,
const FMAIFactoryObject *serializable, GSList **messages );
+FMADataBoxed *nadp_reader_ifactory_provider_read_data ( const FMAIFactoryProvider *reader, void
*reader_data, const FMAIFactoryObject *serializable, const FMADataDef *iddef, GSList **messages );
+void nadp_reader_ifactory_provider_read_done ( const FMAIFactoryProvider *reader, void *reader_data,
const FMAIFactoryObject *serializable, GSList **messages );
G_END_DECLS
diff --git a/src/io-desktop/nadp-writer.c b/src/io-desktop/nadp-writer.c
index c84b4f9..17fbc9c 100644
--- a/src/io-desktop/nadp-writer.c
+++ b/src/io-desktop/nadp-writer.c
@@ -37,7 +37,7 @@
#include <api/fma-core-utils.h>
#include <api/fma-data-types.h>
#include <api/na-object-api.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include "nadp-desktop-file.h"
#include "nadp-desktop-provider.h"
@@ -222,7 +222,7 @@ write_item( const NAIIOProvider *provider, const NAObjectItem *item, NadpDesktop
g_return_val_if_fail( NA_IS_IIO_PROVIDER( provider ), ret );
g_return_val_if_fail( NADP_IS_DESKTOP_PROVIDER( provider ), ret );
- g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( provider ), ret );
+ g_return_val_if_fail( FMA_IS_IFACTORY_PROVIDER( provider ), ret );
g_return_val_if_fail( NA_IS_OBJECT_ITEM( item ), ret );
g_return_val_if_fail( FMA_IS_IFACTORY_OBJECT( item ), ret );
@@ -237,7 +237,7 @@ write_item( const NAIIOProvider *provider, const NAObjectItem *item, NadpDesktop
ret = NA_IIO_PROVIDER_CODE_OK;
- na_ifactory_provider_write_item( NA_IFACTORY_PROVIDER( provider ), ndf, FMA_IFACTORY_OBJECT( item ),
messages );
+ fma_ifactory_provider_write_item( FMA_IFACTORY_PROVIDER( provider ), ndf, FMA_IFACTORY_OBJECT( item
), messages );
if( !nadp_desktop_file_write( ndf )){
ret = NA_IIO_PROVIDER_CODE_WRITE_ERROR;
@@ -386,7 +386,7 @@ nadp_writer_iexporter_export_to_buffer( const FMAIExporter *instance, FMAIExport
} else {
ndf = nadp_desktop_file_new();
- write_code = na_ifactory_provider_write_item( NA_IFACTORY_PROVIDER( instance ), ndf,
FMA_IFACTORY_OBJECT( parms->exported ), &parms->messages );
+ write_code = fma_ifactory_provider_write_item( FMA_IFACTORY_PROVIDER( instance ),
ndf, FMA_IFACTORY_OBJECT( parms->exported ), &parms->messages );
if( write_code != NA_IIO_PROVIDER_CODE_OK ){
code = FMA_IEXPORTER_CODE_ERROR;
@@ -454,7 +454,7 @@ nadp_writer_iexporter_export_to_file( const FMAIExporter *instance, FMAIExporter
g_free( folder_path );
ndf = nadp_desktop_file_new_for_write( dest_path );
- write_code = na_ifactory_provider_write_item( NA_IFACTORY_PROVIDER( instance ), ndf,
FMA_IFACTORY_OBJECT( parms->exported ), &parms->messages );
+ write_code = fma_ifactory_provider_write_item( FMA_IFACTORY_PROVIDER( instance ),
ndf, FMA_IFACTORY_OBJECT( parms->exported ), &parms->messages );
if( write_code != NA_IIO_PROVIDER_CODE_OK ){
code = FMA_IEXPORTER_CODE_ERROR;
@@ -473,7 +473,7 @@ nadp_writer_iexporter_export_to_file( const FMAIExporter *instance, FMAIExporter
}
guint
-nadp_writer_ifactory_provider_write_start( const NAIFactoryProvider *provider, void *writer_data,
+nadp_writer_ifactory_provider_write_start( const FMAIFactoryProvider *provider, void *writer_data,
const FMAIFactoryObject *object, GSList **messages )
{
if( NA_IS_OBJECT_ITEM( object )){
@@ -499,7 +499,7 @@ write_start_write_type( NadpDesktopFile *ndp, NAObjectItem *item )
*/
guint
nadp_writer_ifactory_provider_write_data(
- const NAIFactoryProvider *provider, void *writer_data, const
FMAIFactoryObject *object,
+ const FMAIFactoryProvider *provider, void *writer_data, const
FMAIFactoryObject *object,
const FMADataBoxed *boxed, GSList **messages )
{
static const gchar *thisfn = "nadp_writer_ifactory_provider_write_data";
@@ -589,7 +589,7 @@ nadp_writer_ifactory_provider_write_data(
}
guint
-nadp_writer_ifactory_provider_write_done( const NAIFactoryProvider *provider, void *writer_data,
+nadp_writer_ifactory_provider_write_done( const FMAIFactoryProvider *provider, void *writer_data,
const FMAIFactoryObject *object, GSList **messages )
{
if( NA_IS_OBJECT_ITEM( object )){
diff --git a/src/io-desktop/nadp-writer.h b/src/io-desktop/nadp-writer.h
index aa518e2..f2adb3e 100644
--- a/src/io-desktop/nadp-writer.h
+++ b/src/io-desktop/nadp-writer.h
@@ -32,7 +32,7 @@
#include <api/na-iio-provider.h>
#include <api/fma-iexporter.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
G_BEGIN_DECLS
@@ -47,15 +47,15 @@ guint nadp_writer_iexporter_export_to_buffer( const FMAIExporter *instance, F
guint nadp_writer_iexporter_export_to_file ( const FMAIExporter *instance, FMAIExporterFileParmsv2
*parms );
guint nadp_writer_ifactory_provider_write_start(
- const NAIFactoryProvider *provider, void *writer_data, const
FMAIFactoryObject *object,
+ const FMAIFactoryProvider *provider, void *writer_data, const
FMAIFactoryObject *object,
GSList **messages );
guint nadp_writer_ifactory_provider_write_data(
- const NAIFactoryProvider *provider, void *writer_data, const
FMAIFactoryObject *object,
+ const FMAIFactoryProvider *provider, void *writer_data, const
FMAIFactoryObject *object,
const FMADataBoxed *boxed, GSList **messages );
guint nadp_writer_ifactory_provider_write_done(
- const NAIFactoryProvider *provider, void *writer_data, const
FMAIFactoryObject *object,
+ const FMAIFactoryProvider *provider, void *writer_data, const
FMAIFactoryObject *object,
GSList **messages );
G_END_DECLS
diff --git a/src/io-gconf/nagp-gconf-provider.c b/src/io-gconf/nagp-gconf-provider.c
index e00bb79..aa98a3c 100644
--- a/src/io-gconf/nagp-gconf-provider.c
+++ b/src/io-gconf/nagp-gconf-provider.c
@@ -34,7 +34,7 @@
#include <glib/gi18n.h>
#include <string.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include <api/na-iio-provider.h>
#include <api/fma-gconf-monitor.h>
@@ -66,8 +66,8 @@ static gchar *iio_provider_get_id( const NAIIOProvider *provider );
static gchar *iio_provider_get_name( const NAIIOProvider *provider );
static guint iio_provider_get_version( const NAIIOProvider *provider );
-static void ifactory_provider_iface_init( NAIFactoryProviderInterface *iface );
-static guint ifactory_provider_get_version( const NAIFactoryProvider *provider );
+static void ifactory_provider_iface_init( FMAIFactoryProviderInterface *iface );
+static guint ifactory_provider_get_version( const FMAIFactoryProvider *provider );
#ifdef NA_ENABLE_DEPRECATED
static GList *install_monitors( NagpGConfProvider *provider );
@@ -117,7 +117,7 @@ nagp_gconf_provider_register_type( GTypeModule *module )
g_type_module_add_interface( module, st_module_type, NA_TYPE_IIO_PROVIDER, &iio_provider_iface_info );
- g_type_module_add_interface( module, st_module_type, NA_TYPE_IFACTORY_PROVIDER,
&ifactory_provider_iface_info );
+ g_type_module_add_interface( module, st_module_type, FMA_TYPE_IFACTORY_PROVIDER,
&ifactory_provider_iface_info );
}
static void
@@ -254,7 +254,7 @@ iio_provider_get_version( const NAIIOProvider *provider )
}
static void
-ifactory_provider_iface_init( NAIFactoryProviderInterface *iface )
+ifactory_provider_iface_init( FMAIFactoryProviderInterface *iface )
{
static const gchar *thisfn = "nagp_gconf_provider_ifactory_provider_iface_init";
@@ -276,7 +276,7 @@ ifactory_provider_iface_init( NAIFactoryProviderInterface *iface )
}
static guint
-ifactory_provider_get_version( const NAIFactoryProvider *provider )
+ifactory_provider_get_version( const FMAIFactoryProvider *provider )
{
return( 1 );
}
diff --git a/src/io-gconf/nagp-reader.c b/src/io-gconf/nagp-reader.c
index 9aea50d..10ab971 100644
--- a/src/io-gconf/nagp-reader.c
+++ b/src/io-gconf/nagp-reader.c
@@ -35,7 +35,7 @@
#include <api/fma-data-def.h>
#include <api/fma-data-types.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include <api/na-iio-provider.h>
#include <api/na-object-api.h>
#include <api/fma-core-utils.h>
@@ -54,11 +54,11 @@ typedef struct {
static NAObjectItem *read_item( NagpGConfProvider *provider, const gchar *path, GSList **messages );
-static void read_start_profile_attach_profile( const NAIFactoryProvider *provider, NAObjectProfile
*profile, ReaderData *data, GSList **messages );
+static void read_start_profile_attach_profile( const FMAIFactoryProvider *provider, NAObjectProfile
*profile, ReaderData *data, GSList **messages );
-static gboolean read_done_item_is_writable( const NAIFactoryProvider *provider, NAObjectItem *item,
ReaderData *data, GSList **messages );
-static void read_done_action_read_profiles( const NAIFactoryProvider *provider, NAObjectAction
*action, ReaderData *data, GSList **messages );
-static void read_done_action_load_profile( const NAIFactoryProvider *provider, ReaderData *data,
const gchar *path, GSList **messages );
+static gboolean read_done_item_is_writable( const FMAIFactoryProvider *provider, NAObjectItem *item,
ReaderData *data, GSList **messages );
+static void read_done_action_read_profiles( const FMAIFactoryProvider *provider, NAObjectAction
*action, ReaderData *data, GSList **messages );
+static void read_done_action_load_profile( const FMAIFactoryProvider *provider, ReaderData *data,
const gchar *path, GSList **messages );
static FMADataBoxed *get_boxed_from_path( const NagpGConfProvider *provider, const gchar *path, ReaderData
*reader_data, const FMADataDef *def );
static gboolean is_key_writable( NagpGConfProvider *gconf, const gchar *key );
@@ -152,8 +152,8 @@ read_item( NagpGConfProvider *provider, const gchar *path, GSList **messages )
data->entries = fma_gconf_utils_get_entries( provider->private->gconf, path );
fma_gconf_utils_dump_entries( data->entries );
- na_ifactory_provider_read_item(
- NA_IFACTORY_PROVIDER( provider ),
+ fma_ifactory_provider_read_item(
+ FMA_IFACTORY_PROVIDER( provider ),
data,
FMA_IFACTORY_OBJECT( item ),
messages );
@@ -166,11 +166,11 @@ read_item( NagpGConfProvider *provider, const gchar *path, GSList **messages )
}
void
-nagp_reader_read_start( const NAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, GSList **messages )
+nagp_reader_read_start( const FMAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, GSList **messages )
{
static const gchar *thisfn = "nagp_reader_read_start";
- g_return_if_fail( NA_IS_IFACTORY_PROVIDER( provider ));
+ g_return_if_fail( FMA_IS_IFACTORY_PROVIDER( provider ));
g_return_if_fail( NAGP_IS_GCONF_PROVIDER( provider ));
g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
@@ -190,18 +190,18 @@ nagp_reader_read_start( const NAIFactoryProvider *provider, void *reader_data, c
}
static void
-read_start_profile_attach_profile( const NAIFactoryProvider *provider, NAObjectProfile *profile, ReaderData
*data, GSList **messages )
+read_start_profile_attach_profile( const FMAIFactoryProvider *provider, NAObjectProfile *profile, ReaderData
*data, GSList **messages )
{
na_object_attach_profile( data->parent, profile );
}
FMADataBoxed *
-nagp_reader_read_data( const NAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, const FMADataDef *def, GSList **messages )
+nagp_reader_read_data( const FMAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, const FMADataDef *def, GSList **messages )
{
static const gchar *thisfn = "nagp_reader_read_data";
FMADataBoxed *boxed;
- g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( provider ), NULL );
+ g_return_val_if_fail( FMA_IS_IFACTORY_PROVIDER( provider ), NULL );
g_return_val_if_fail( FMA_IS_IFACTORY_OBJECT( object ), NULL );
/*g_debug( "%s: reader_data=%p, object=%p (%s), data=%s",
@@ -222,12 +222,12 @@ nagp_reader_read_data( const NAIFactoryProvider *provider, void *reader_data, co
}
void
-nagp_reader_read_done( const NAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, GSList **messages )
+nagp_reader_read_done( const FMAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, GSList **messages )
{
static const gchar *thisfn = "nagp_reader_read_done";
gboolean writable;
- g_return_if_fail( NA_IS_IFACTORY_PROVIDER( provider ));
+ g_return_if_fail( FMA_IS_IFACTORY_PROVIDER( provider ));
g_return_if_fail( NAGP_IS_GCONF_PROVIDER( provider ));
g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
@@ -254,7 +254,7 @@ nagp_reader_read_done( const NAIFactoryProvider *provider, void *reader_data, co
}
static gboolean
-read_done_item_is_writable( const NAIFactoryProvider *provider, NAObjectItem *item, ReaderData *data, GSList
**messages )
+read_done_item_is_writable( const FMAIFactoryProvider *provider, NAObjectItem *item, ReaderData *data,
GSList **messages )
{
GSList *ie;
gboolean writable;
@@ -276,7 +276,7 @@ read_done_item_is_writable( const NAIFactoryProvider *provider, NAObjectItem *it
}
static void
-read_done_action_read_profiles( const NAIFactoryProvider *provider, NAObjectAction *action, ReaderData
*data, GSList **messages )
+read_done_action_read_profiles( const FMAIFactoryProvider *provider, NAObjectAction *action, ReaderData
*data, GSList **messages )
{
static const gchar *thisfn = "nagp_reader_read_done_action_read_profiles";
GSList *order;
@@ -329,7 +329,7 @@ read_done_action_read_profiles( const NAIFactoryProvider *provider, NAObjectActi
}
static void
-read_done_action_load_profile( const NAIFactoryProvider *provider, ReaderData *data, const gchar *path,
GSList **messages )
+read_done_action_load_profile( const FMAIFactoryProvider *provider, ReaderData *data, const gchar *path,
GSList **messages )
{
gchar *id;
ReaderData *profile_data;
@@ -345,8 +345,8 @@ read_done_action_load_profile( const NAIFactoryProvider *provider, ReaderData *d
profile_data->path = ( gchar * ) path;
profile_data->entries = fma_gconf_utils_get_entries( NAGP_GCONF_PROVIDER( provider )->private->gconf,
path );
- na_ifactory_provider_read_item(
- NA_IFACTORY_PROVIDER( provider ),
+ fma_ifactory_provider_read_item(
+ FMA_IFACTORY_PROVIDER( provider ),
profile_data,
FMA_IFACTORY_OBJECT( profile ),
messages );
diff --git a/src/io-gconf/nagp-reader.h b/src/io-gconf/nagp-reader.h
index c3fb77c..7a5501d 100644
--- a/src/io-gconf/nagp-reader.h
+++ b/src/io-gconf/nagp-reader.h
@@ -31,15 +31,15 @@
#define __NAGP_READER_H__
#include <api/na-iio-provider.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
G_BEGIN_DECLS
GList *nagp_iio_provider_read_items( const NAIIOProvider *provider, GSList **messages );
-void nagp_reader_read_start( const NAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
-FMADataBoxed *nagp_reader_read_data ( const NAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, const FMADataDef *def, GSList **messages );
-void nagp_reader_read_done ( const NAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
+void nagp_reader_read_start( const FMAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
+FMADataBoxed *nagp_reader_read_data ( const FMAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, const FMADataDef *def, GSList **messages );
+void nagp_reader_read_done ( const FMAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
G_END_DECLS
diff --git a/src/io-gconf/nagp-writer.c b/src/io-gconf/nagp-writer.c
index 0f4439d..bb2152b 100644
--- a/src/io-gconf/nagp-writer.c
+++ b/src/io-gconf/nagp-writer.c
@@ -36,7 +36,7 @@
#include <api/fma-data-def.h>
#include <api/fma-data-types.h>
#include <api/na-iio-provider.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include <api/na-object-api.h>
#include <api/fma-core-utils.h>
#include <api/fma-gconf-utils.h>
@@ -153,7 +153,7 @@ nagp_iio_provider_write_item( const NAIIOProvider *provider, const NAObjectItem
ret = nagp_iio_provider_delete_item( provider, item, messages );
if( ret == NA_IIO_PROVIDER_CODE_OK ){
- na_ifactory_provider_write_item( NA_IFACTORY_PROVIDER( provider ), NULL, FMA_IFACTORY_OBJECT(
item ), messages );
+ fma_ifactory_provider_write_item( FMA_IFACTORY_PROVIDER( provider ), NULL,
FMA_IFACTORY_OBJECT( item ), messages );
}
gconf_client_suggest_sync( self->private->gconf, NULL );
@@ -233,7 +233,7 @@ nagp_iio_provider_delete_item( const NAIIOProvider *provider, const NAObjectItem
}
guint
-nagp_writer_write_start( const NAIFactoryProvider *writer, void *writer_data,
+nagp_writer_write_start( const FMAIFactoryProvider *writer, void *writer_data,
const FMAIFactoryObject *object, GSList **messages )
{
if( NA_IS_OBJECT_ITEM( object )){
@@ -279,7 +279,7 @@ write_start_write_version( NagpGConfProvider *provider, NAObjectItem *item )
}
guint
-nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
+nagp_writer_write_data( const FMAIFactoryProvider *provider, void *writer_data,
const FMAIFactoryObject *object,
const FMADataBoxed *boxed,
GSList **messages )
{
@@ -387,7 +387,7 @@ nagp_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
}
guint
-nagp_writer_write_done( const NAIFactoryProvider *writer, void *writer_data,
+nagp_writer_write_done( const FMAIFactoryProvider *writer, void *writer_data,
const FMAIFactoryObject *object,
GSList **messages )
{
diff --git a/src/io-gconf/nagp-writer.h b/src/io-gconf/nagp-writer.h
index 62cf593..70f4538 100644
--- a/src/io-gconf/nagp-writer.h
+++ b/src/io-gconf/nagp-writer.h
@@ -32,7 +32,7 @@
#include <api/fma-data-boxed.h>
#include <api/na-iio-provider.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
G_BEGIN_DECLS
@@ -51,17 +51,17 @@ guint nagp_iio_provider_write_item ( const NAIIOProvider *provider,
guint nagp_iio_provider_delete_item ( const NAIIOProvider *provider,
const
NAObjectItem *item, GSList **message );
-/* NAIFactoryProvider interface
+/* FMAIFactoryProvider interface
*/
-guint nagp_writer_write_start( const NAIFactoryProvider *writer, void *writer_data,
+guint nagp_writer_write_start( const FMAIFactoryProvider *writer, void *writer_data,
const FMAIFactoryObject *object,
GSList **messages );
-guint nagp_writer_write_data ( const NAIFactoryProvider *provider, void *writer_data,
+guint nagp_writer_write_data ( const FMAIFactoryProvider *provider, void *writer_data,
const FMAIFactoryObject *object,
const FMADataBoxed *boxed,
GSList **messages );
-guint nagp_writer_write_done ( const NAIFactoryProvider *writer, void *writer_data,
+guint nagp_writer_write_done ( const FMAIFactoryProvider *writer, void *writer_data,
const FMAIFactoryObject *object,
GSList **messages );
#endif /* NA_ENABLE_DEPRECATED */
diff --git a/src/io-xml/naxml-provider.c b/src/io-xml/naxml-provider.c
index 68e9129..cb9e5e5 100644
--- a/src/io-xml/naxml-provider.c
+++ b/src/io-xml/naxml-provider.c
@@ -31,7 +31,7 @@
#include <config.h>
#endif
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include <api/fma-iexporter.h>
#include <api/na-iimporter.h>
@@ -69,8 +69,8 @@ static gchar *iexporter_get_name( const FMAIExporter *exporter );
static void *iexporter_get_formats( const FMAIExporter *exporter );
static void iexporter_free_formats( const FMAIExporter *exporter, GList *format_list );
-static void ifactory_provider_iface_init( NAIFactoryProviderInterface *iface );
-static guint ifactory_provider_get_version( const NAIFactoryProvider *factory );
+static void ifactory_provider_iface_init( FMAIFactoryProviderInterface *iface );
+static guint ifactory_provider_get_version( const FMAIFactoryProvider *factory );
GType
naxml_provider_get_type( void )
@@ -121,7 +121,7 @@ naxml_provider_register_type( GTypeModule *module )
g_type_module_add_interface( module, st_module_type, FMA_TYPE_IEXPORTER, &iexporter_iface_info );
- g_type_module_add_interface( module, st_module_type, NA_TYPE_IFACTORY_PROVIDER,
&ifactory_provider_iface_info );
+ g_type_module_add_interface( module, st_module_type, FMA_TYPE_IFACTORY_PROVIDER,
&ifactory_provider_iface_info );
}
static void
@@ -259,7 +259,7 @@ iexporter_free_formats( const FMAIExporter *exporter, GList *format_list )
}
static void
-ifactory_provider_iface_init( NAIFactoryProviderInterface *iface )
+ifactory_provider_iface_init( FMAIFactoryProviderInterface *iface )
{
static const gchar *thisfn = "naxml_provider_ifactory_provider_iface_init";
@@ -275,7 +275,7 @@ ifactory_provider_iface_init( NAIFactoryProviderInterface *iface )
}
static guint
-ifactory_provider_get_version( const NAIFactoryProvider *factory )
+ifactory_provider_get_version( const FMAIFactoryProvider *factory )
{
return( 1 );
}
diff --git a/src/io-xml/naxml-reader.h b/src/io-xml/naxml-reader.h
index 4cba835..88dc67e 100644
--- a/src/io-xml/naxml-reader.h
+++ b/src/io-xml/naxml-reader.h
@@ -46,7 +46,7 @@
#include <api/fma-data-boxed.h>
#include <api/na-iimporter.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
G_BEGIN_DECLS
@@ -79,9 +79,9 @@ GType naxml_reader_get_type( void );
guint naxml_reader_import_from_uri( const NAIImporter *instance, void *parms_ptr );
-void naxml_reader_read_start( const NAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
-FMADataBoxed *naxml_reader_read_data ( const NAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, const FMADataDef *def, GSList **messages );
-void naxml_reader_read_done ( const NAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
+void naxml_reader_read_start( const FMAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
+FMADataBoxed *naxml_reader_read_data ( const FMAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, const FMADataDef *def, GSList **messages );
+void naxml_reader_read_done ( const FMAIFactoryProvider *provider, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
G_END_DECLS
diff --git a/src/io-xml/naxml-writer.c b/src/io-xml/naxml-writer.c
index 9744ad8..0069d8b 100644
--- a/src/io-xml/naxml-writer.c
+++ b/src/io-xml/naxml-writer.c
@@ -39,7 +39,7 @@
#include <api/fma-core-utils.h>
#include <api/fma-data-types.h>
#include <api/na-object-api.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include <api/na-iio-provider.h>
#include <io-gconf/nagp-keys.h>
@@ -399,8 +399,8 @@ build_xml_doc( NAXMLWriter *writer )
writer->private->root_node = xmlNewNode( NULL, BAD_CAST( writer->private->fn_str->root_node ));
xmlDocSetRootElement( writer->private->doc, writer->private->root_node );
- na_ifactory_provider_write_item(
- NA_IFACTORY_PROVIDER( writer->private->provider ),
+ fma_ifactory_provider_write_item(
+ FMA_IFACTORY_PROVIDER( writer->private->provider ),
writer,
FMA_IFACTORY_OBJECT( writer->private->exported ),
writer->private->messages ? & writer->private->messages : NULL );
@@ -409,7 +409,7 @@ build_xml_doc( NAXMLWriter *writer )
}
guint
-naxml_writer_write_start( const NAIFactoryProvider *provider, void *writer_data, const FMAIFactoryObject
*object, GSList **messages )
+naxml_writer_write_start( const FMAIFactoryProvider *provider, void *writer_data, const FMAIFactoryObject
*object, GSList **messages )
{
NAXMLWriter *writer;
FMADataGroup *groups;
@@ -471,7 +471,7 @@ write_start_write_version( NAXMLWriter *writer, NAObjectItem *object, const FMAD
}
guint
-naxml_writer_write_data( const NAIFactoryProvider *provider, void *writer_data, const FMAIFactoryObject
*object, const FMADataBoxed *boxed, GSList **messages )
+naxml_writer_write_data( const FMAIFactoryProvider *provider, void *writer_data, const FMAIFactoryObject
*object, const FMADataBoxed *boxed, GSList **messages )
{
NAXMLWriter *writer;
const FMADataDef *def;
@@ -497,7 +497,7 @@ naxml_writer_write_data( const NAIFactoryProvider *provider, void *writer_data,
}
guint
-naxml_writer_write_done( const NAIFactoryProvider *provider, void *writer_data, const FMAIFactoryObject
*object, GSList **messages )
+naxml_writer_write_done( const FMAIFactoryProvider *provider, void *writer_data, const FMAIFactoryObject
*object, GSList **messages )
{
return( NA_IIO_PROVIDER_CODE_OK );
}
diff --git a/src/io-xml/naxml-writer.h b/src/io-xml/naxml-writer.h
index 6de91b2..5e7c02b 100644
--- a/src/io-xml/naxml-writer.h
+++ b/src/io-xml/naxml-writer.h
@@ -40,7 +40,7 @@
#include <api/fma-data-boxed.h>
#include <api/fma-iexporter.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
G_BEGIN_DECLS
@@ -74,9 +74,9 @@ GType naxml_writer_get_type( void );
guint naxml_writer_export_to_buffer( const FMAIExporter *instance, FMAIExporterBufferParmsv2 *parms );
guint naxml_writer_export_to_file ( const FMAIExporter *instance, FMAIExporterFileParmsv2 *parms );
-guint naxml_writer_write_start( const NAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, GSList **messages );
-guint naxml_writer_write_data ( const NAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, const FMADataBoxed *boxed, GSList **messages );
-guint naxml_writer_write_done ( const NAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, GSList **messages );
+guint naxml_writer_write_start( const FMAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, GSList **messages );
+guint naxml_writer_write_data ( const FMAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, const FMADataBoxed *boxed, GSList **messages );
+guint naxml_writer_write_done ( const FMAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, GSList **messages );
G_END_DECLS
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/src/api/na-ifactory-provider.h b/src/api/fma-ifactory-provider.h
similarity index 72%
rename from src/api/na-ifactory-provider.h
rename to src/api/fma-ifactory-provider.h
index 6504695..f8bbf50 100644
--- a/src/api/na-ifactory-provider.h
+++ b/src/api/fma-ifactory-provider.h
@@ -27,12 +27,12 @@
* ... and many others (see AUTHORS)
*/
-#ifndef __FILE_MANAGER_ACTIONS_API_NA_IFACTORY_PROVIDER_H__
-#define __FILE_MANAGER_ACTIONS_API_NA_IFACTORY_PROVIDER_H__
+#ifndef __FILE_MANAGER_ACTIONS_API_IFACTORY_PROVIDER_H__
+#define __FILE_MANAGER_ACTIONS_API_IFACTORY_PROVIDER_H__
/**
* SECTION: ifactory-provider
- * @title: NAIFactoryProvider
+ * @title: FMAIFactoryProvider
* @short_description: The Data Factory Provider Interface v 1
* @include: file-manager-actions/na-ifactory_provider.h
*
@@ -45,7 +45,7 @@
* (historical storage subsystem) GConf; import and export assistants
* must be carefully updated to export the new data...
*
* The #NAIFactoryProvider aims to simplify and organize all the work
* which must be done around each and every elementary data. It is based
* on three main things:
*
@@ -84,7 +84,7 @@
* </orderedlist>
*
* Of course, I/O providers are good candidates to be users of this
- * #NAIFactoryProvider interface.
+ * #FMAIFactoryProvider interface.
*
* Without this interface, each and every I/O provider must,
* for example when reading an item, have the list of data to be
@@ -94,7 +94,7 @@
* then all available I/O providers must be updated: read the data,
* write the data, then display the data, and so on..
*
* With this #NAIFactoryProvider interface, the I/O provider has just to
* deal with reading/writing elementary types. It does need to know that
* it will have to read, name, tooltip, description. It just needs to know
* how to read a string.
@@ -110,7 +110,7 @@
* <refsect2>
* <title>Versions historic</title>
* <table>
* <title>Historic of the versions of the #NAIFactoryProvider interface</title>
* <tgroup rowsep="1" colsep="1" align="center" cols="3">
* <colspec colname="na-version" />
* <colspec colname="api-version" />
@@ -118,7 +118,7 @@
* <thead>
* <row>
* <entry>&prodname; version</entry>
- * <entry>#NAIFactoryProvider interface version</entry>
+ * <entry>#FMAIFactoryProvider interface version</entry>
* <entry></entry>
* </row>
* </thead>
@@ -136,19 +136,19 @@
#include "fma-data-boxed.h"
#include "fma-ifactory-object.h"
-#include "na-ifactory-provider-provider.h"
+#include "fma-ifactory-provider-provider.h"
G_BEGIN_DECLS
-#define NA_TYPE_IFACTORY_PROVIDER ( na_ifactory_provider_get_type())
-#define NA_IFACTORY_PROVIDER( instance ) ( G_TYPE_CHECK_INSTANCE_CAST( instance,
NA_TYPE_IFACTORY_PROVIDER, NAIFactoryProvider ))
-#define NA_IS_IFACTORY_PROVIDER( instance ) ( G_TYPE_CHECK_INSTANCE_TYPE( instance,
NA_TYPE_IFACTORY_PROVIDER ))
-#define NA_IFACTORY_PROVIDER_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ),
NA_TYPE_IFACTORY_PROVIDER, NAIFactoryProviderInterface ))
+#define FMA_TYPE_IFACTORY_PROVIDER ( fma_ifactory_provider_get_type())
+#define FMA_IFACTORY_PROVIDER( instance ) ( G_TYPE_CHECK_INSTANCE_CAST( instance,
FMA_TYPE_IFACTORY_PROVIDER, FMAIFactoryProvider ))
+#define FMA_IS_IFACTORY_PROVIDER( instance ) ( G_TYPE_CHECK_INSTANCE_TYPE( instance,
FMA_TYPE_IFACTORY_PROVIDER ))
+#define FMA_IFACTORY_PROVIDER_GET_INTERFACE( instance ) ( G_TYPE_INSTANCE_GET_INTERFACE(( instance ),
FMA_TYPE_IFACTORY_PROVIDER, FMAIFactoryProviderInterface ))
-typedef struct _NAIFactoryProviderInterfacePrivate NAIFactoryProviderInterfacePrivate;
+typedef struct _FMAIFactoryProviderInterfacePrivate FMAIFactoryProviderInterfacePrivate;
/**
- * NAIFactoryProviderInterface:
+ * FMAIFactoryProviderInterface:
* @get_version: returns the version of this interface the plugin implements.
* @read_start: triggered just before reading an item.
* @read_data: reads an item.
@@ -157,17 +157,17 @@ typedef struct _NAIFactoryProviderInterfacePrivate NAIFactoryProviderInterfa
* @write_data: writes an item.
* @write_done: triggered at the end of item writing.
*
* This defines the interface that a #NAIFactoryProvider may implement.
*/
typedef struct {
/*< private >*/
- GTypeInterface parent;
- NAIFactoryProviderInterfacePrivate *private;
+ GTypeInterface parent;
+ FMAIFactoryProviderInterfacePrivate *private;
/*< public >*/
/**
* get_version:
- * @instance: this #NAIFactoryProvider instance.
+ * @instance: this #FMAIFactoryProvider instance.
*
* Defaults to 1.
*
@@ -175,13 +175,13 @@ typedef struct {
*
* Since: 2.30
*/
- guint ( *get_version )( const NAIFactoryProvider *instance );
+ guint ( *get_version )( const FMAIFactoryProvider *instance );
/**
* read_start:
- * @reader: this #NAIFactoryProvider instance.
+ * @reader: this #FMAIFactoryProvider instance.
* @reader_data: the data associated to this instance, as provided
* when na_ifactory_provider_read_item() was called.
* @object: the #FMAIFactoryObject object which comes to be read.
* @messages: a pointer to a #GSList list of strings; the provider
* may append messages to this list, but shouldn't reinitialize it.
@@ -190,13 +190,13 @@ typedef struct {
*
* Since: 2.30
*/
- void ( *read_start ) ( const NAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
+ void ( *read_start ) ( const FMAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
/**
* read_data:
- * @reader: this #NAIFactoryProvider instance.
+ * @reader: this #FMAIFactoryProvider instance.
* @reader_data: the data associated to this instance, as provided
* when na_ifactory_provider_read_item() was called.
* @object: the #NAIFactoryobject being unserialized.
* @def: a #FMADataDef structure which identifies the data to be unserialized.
* @messages: a pointer to a #GSList list of strings; the provider
@@ -209,13 +209,13 @@ typedef struct {
*
* Since: 2.30
*/
- FMADataBoxed * ( *read_data ) ( const NAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *object, const FMADataDef *def, GSList **messages );
+ FMADataBoxed * ( *read_data ) ( const FMAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *object, const FMADataDef *def, GSList **messages );
/**
* read_done:
- * @reader: this #NAIFactoryProvider instance.
+ * @reader: this #FMAIFactoryProvider instance.
* @reader_data: the data associated to this instance, as provided
* when na_ifactory_provider_read_item() was called.
* @object: the #FMAIFactoryObject object which comes to be read.
* @messages: a pointer to a #GSList list of strings; the provider
* may append messages to this list, but shouldn't reinitialize it.
@@ -225,11 +225,11 @@ typedef struct {
*
* Since: 2.30
*/
- void ( *read_done ) ( const NAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
+ void ( *read_done ) ( const FMAIFactoryProvider *reader, void *reader_data, const
FMAIFactoryObject *object, GSList **messages );
/**
* write_start:
- * @writer: this #NAIFactoryProvider instance.
+ * @writer: this #FMAIFactoryProvider instance.
* @writer_data: the data associated to this instance.
* @object: the #FMAIFactoryObject object which comes to be written.
* @messages: a pointer to a #GSList list of strings; the provider
@@ -241,11 +241,11 @@ typedef struct {
*
* Since: 2.30
*/
- guint ( *write_start )( const NAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, GSList **messages );
+ guint ( *write_start )( const FMAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, GSList **messages );
/**
* write_data:
- * @writer: this #NAIFactoryProvider instance.
+ * @writer: this #FMAIFactoryProvider instance.
* @writer_data: the data associated to this instance.
* @object: the #FMAIFactoryObject object being written.
* @def: the description of the data to be written.
@@ -261,11 +261,11 @@ typedef struct {
*
* Since: 2.30
*/
- guint ( *write_data ) ( const NAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, const FMADataBoxed *boxed, GSList **messages );
+ guint ( *write_data ) ( const FMAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, const FMADataBoxed *boxed, GSList **messages );
/**
* write_done:
- * @writer: this #NAIFactoryProvider instance.
+ * @writer: this #FMAIFactoryProvider instance.
* @writer_data: the data associated to this instance.
* @object: the #FMAIFactoryObject object which comes to be written.
* @messages: a pointer to a #GSList list of strings; the provider
@@ -278,15 +278,15 @@ typedef struct {
*
* Since: 2.30
*/
- guint ( *write_done ) ( const NAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, GSList **messages );
+ guint ( *write_done ) ( const FMAIFactoryProvider *writer, void *writer_data, const
FMAIFactoryObject *object, GSList **messages );
}
- NAIFactoryProviderInterface;
+ FMAIFactoryProviderInterface;
-GType na_ifactory_provider_get_type( void );
+GType fma_ifactory_provider_get_type ( void );
-void na_ifactory_provider_read_item ( const NAIFactoryProvider *reader, void *reader_data,
FMAIFactoryObject *object, GSList **messages );
-guint na_ifactory_provider_write_item( const NAIFactoryProvider *writer, void *writer_data,
FMAIFactoryObject *object, GSList **messages );
+void fma_ifactory_provider_read_item ( const FMAIFactoryProvider *reader, void *reader_data,
FMAIFactoryObject *object, GSList **messages );
+guint fma_ifactory_provider_write_item( const FMAIFactoryProvider *writer, void *writer_data,
FMAIFactoryObject *object, GSList **messages );
G_END_DECLS
-#endif /* __FILE_MANAGER_ACTIONS_API_NA_IFACTORY_PROVIDER_H__ */
+#endif /* __FILE_MANAGER_ACTIONS_API_IFACTORY_PROVIDER_H__ */
@@ -45,7 +45,7 @@
* must be carefully updated to export the new data...
*
- * The #NAIFactoryProvider aims to simplify and organize all the work
+ * The #FMAIFactoryProvider aims to simplify and organize all the work
* which must be done around each and every elementary data. It is based
* on three main things:
@@ -94,7 +94,7 @@
* write the data, then display the data, and so on..
*
- * With this #NAIFactoryProvider interface, the I/O provider has just to
+ * With this #FMAIFactoryProvider interface, the I/O provider has just to
* deal with reading/writing elementary types. It does need to know that
* it will have to read, name, tooltip, description. It just needs to know
@@ -110,7 +110,7 @@
* <title>Versions historic</title>
* <table>
- * <title>Historic of the versions of the #NAIFactoryProvider interface</title>
+ * <title>Historic of the versions of the #FMAIFactoryProvider interface</title>
* <tgroup rowsep="1" colsep="1" align="center" cols="3">
* <colspec colname="na-version" />
@@ -157,17 +157,17 @@ typedef struct _NAIFactoryProviderInterfacePrivate NAIFactoryProviderInterfa
* @write_done: triggered at the end of item writing.
*
- * This defines the interface that a #NAIFactoryProvider may implement.
+ * This defines the interface that a #FMAIFactoryProvider may implement.
*/
typedef struct {
@@ -175,13 +175,13 @@ typedef struct {
* @reader_data: the data associated to this instance, as provided
- * when na_ifactory_provider_read_item() was called.
+ * when fma_ifactory_provider_read_item() was called.
* @object: the #FMAIFactoryObject object which comes to be read.
* @messages: a pointer to a #GSList list of strings; the provider
@@ -190,13 +190,13 @@ typedef struct {
* @reader_data: the data associated to this instance, as provided
- * when na_ifactory_provider_read_item() was called.
+ * when fma_ifactory_provider_read_item() was called.
* @object: the #NAIFactoryobject being unserialized.
* @def: a #FMADataDef structure which identifies the data to be unserialized.
@@ -209,13 +209,13 @@ typedef struct {
* @reader_data: the data associated to this instance, as provided
- * when na_ifactory_provider_read_item() was called.
+ * when fma_ifactory_provider_read_item() was called.
* @object: the #FMAIFactoryObject object which comes to be read.
* @messages: a pointer to a #GSList list of strings; the provider
diff --git a/src/core/na-ifactory-provider.c b/src/core/fma-ifactory-provider.c
similarity index 61%
rename from src/core/na-ifactory-provider.c
rename to src/core/fma-ifactory-provider.c
index c3cb2cd..f0613c4 100644
--- a/src/core/na-ifactory-provider.c
+++ b/src/core/fma-ifactory-provider.c
@@ -32,39 +32,39 @@
#endif
#include <api/na-iio-provider.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include "na-factory-object.h"
#include "na-factory-provider.h"
/* private interface data
*/
-struct _NAIFactoryProviderInterfacePrivate {
+struct _FMAIFactoryProviderInterfacePrivate {
void *empty; /* so that gcc -pedantic is happy */
};
static guint st_initializations = 0; /* interface initialization count */
static GType register_type( void );
-static void interface_base_init( NAIFactoryProviderInterface *klass );
-static void interface_base_finalize( NAIFactoryProviderInterface *klass );
+static void interface_base_init( FMAIFactoryProviderInterface *klass );
+static void interface_base_finalize( FMAIFactoryProviderInterface *klass );
-static guint ifactory_provider_get_version( const NAIFactoryProvider *instance );
+static guint ifactory_provider_get_version( const FMAIFactoryProvider *instance );
-static void v_factory_provider_read_start( const NAIFactoryProvider *reader, void *reader_data,
FMAIFactoryObject *serializable, GSList **messages );
-static void v_factory_provider_read_done( const NAIFactoryProvider *reader, void *reader_data,
FMAIFactoryObject *serializable, GSList **messages );
-static guint v_factory_provider_write_start( const NAIFactoryProvider *writer, void *writer_data,
FMAIFactoryObject *serializable, GSList **messages );
-static guint v_factory_provider_write_done( const NAIFactoryProvider *writer, void *writer_data,
FMAIFactoryObject *serializable, GSList **messages );
+static void v_factory_provider_read_start( const FMAIFactoryProvider *reader, void *reader_data,
FMAIFactoryObject *serializable, GSList **messages );
+static void v_factory_provider_read_done( const FMAIFactoryProvider *reader, void *reader_data,
FMAIFactoryObject *serializable, GSList **messages );
+static guint v_factory_provider_write_start( const FMAIFactoryProvider *writer, void *writer_data,
FMAIFactoryObject *serializable, GSList **messages );
+static guint v_factory_provider_write_done( const FMAIFactoryProvider *writer, void *writer_data,
FMAIFactoryObject *serializable, GSList **messages );
/**
- * na_ifactory_provider_get_type:
+ * fma_ifactory_provider_get_type:
*
* Registers the GType of this interface.
*
- * Returns: the #NAIFactoryProvider #GType.
+ * Returns: the #FMAIFactoryProvider #GType.
*/
GType
-na_ifactory_provider_get_type( void )
+fma_ifactory_provider_get_type( void )
{
static GType object_type = 0;
@@ -78,11 +78,11 @@ na_ifactory_provider_get_type( void )
static GType
register_type( void )
{
- static const gchar *thisfn = "na_ifactory_provider_register_type";
+ static const gchar *thisfn = "fma_ifactory_provider_register_type";
GType type;
static const GTypeInfo info = {
- sizeof( NAIFactoryProviderInterface ),
+ sizeof( FMAIFactoryProviderInterface ),
( GBaseInitFunc ) interface_base_init,
( GBaseFinalizeFunc ) interface_base_finalize,
NULL,
@@ -95,7 +95,7 @@ register_type( void )
g_debug( "%s", thisfn );
- type = g_type_register_static( G_TYPE_INTERFACE, "NAIFactoryProvider", &info, 0 );
+ type = g_type_register_static( G_TYPE_INTERFACE, "FMAIFactoryProvider", &info, 0 );
g_type_interface_add_prerequisite( type, G_TYPE_OBJECT );
@@ -103,15 +103,15 @@ register_type( void )
}
static void
-interface_base_init( NAIFactoryProviderInterface *klass )
+interface_base_init( FMAIFactoryProviderInterface *klass )
{
- static const gchar *thisfn = "na_ifactory_provider_interface_base_init";
+ static const gchar *thisfn = "fma_ifactory_provider_interface_base_init";
if( !st_initializations ){
g_debug( "%s: klass=%p (%s)", thisfn, ( void * ) klass, G_OBJECT_CLASS_NAME( klass ));
- klass->private = g_new0( NAIFactoryProviderInterfacePrivate, 1 );
+ klass->private = g_new0( FMAIFactoryProviderInterfacePrivate, 1 );
klass->get_version = ifactory_provider_get_version;
klass->read_start = NULL;
@@ -126,9 +126,9 @@ interface_base_init( NAIFactoryProviderInterface *klass )
}
static void
-interface_base_finalize( NAIFactoryProviderInterface *klass )
+interface_base_finalize( FMAIFactoryProviderInterface *klass )
{
- static const gchar *thisfn = "na_ifactory_provider_interface_base_finalize";
+ static const gchar *thisfn = "fma_ifactory_provider_interface_base_finalize";
st_initializations -= 1;
@@ -141,14 +141,14 @@ interface_base_finalize( NAIFactoryProviderInterface *klass )
}
static guint
-ifactory_provider_get_version( const NAIFactoryProvider *instance )
+ifactory_provider_get_version( const FMAIFactoryProvider *instance )
{
return( 1 );
}
/**
* na_ifactory_provider_read_item:
* @reader: the instance which implements this #NAIFactoryProvider interface.
* @reader_data: instance data which will be provided back to the interface
* methods
* @object: the #FMAIFactoryObject object to be unserialilzed.
@@ -157,8 +157,8 @@ ifactory_provider_get_version( const NAIFactoryProvider *instance )
*
* This function is to be called by a #NAIIOProvider which would wish read
* its items. The function takes care of collecting and structuring data,
- * while the callback interface methods #NAIFactoryProviderInterface.read_start(),
- * #NAIFactoryProviderInterface.read_data() and #NAIFactoryProviderInterface.read_done()
+ * while the callback interface methods #FMAIFactoryProviderInterface.read_start(),
+ * #FMAIFactoryProviderInterface.read_data() and #FMAIFactoryProviderInterface.read_done()
* just have to fill a given #FMADataBoxed with the ad-hoc data type.
*
* <example>
@@ -174,8 +174,8 @@ ifactory_provider_get_version( const NAIFactoryProvider *instance )
* &lcomment;
* * now call interface function
* &rcomment;
- * na_ifactory_provider_read_item(
- * NA_IFACTORY_PROVIDER( provider ),
+ * fma_ifactory_provider_read_item(
+ * FMA_IFACTORY_PROVIDER( provider ),
* data,
* FMA_IFACTORY_OBJECT( item ),
* messages );
@@ -185,9 +185,9 @@ ifactory_provider_get_version( const NAIFactoryProvider *instance )
* Since: 2.30
*/
void
-na_ifactory_provider_read_item( const NAIFactoryProvider *reader, void *reader_data, FMAIFactoryObject
*object, GSList **messages )
+fma_ifactory_provider_read_item( const FMAIFactoryProvider *reader, void *reader_data, FMAIFactoryObject
*object, GSList **messages )
{
- g_return_if_fail( NA_IS_IFACTORY_PROVIDER( reader ));
+ g_return_if_fail( FMA_IS_IFACTORY_PROVIDER( reader ));
g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
v_factory_provider_read_start( reader, reader_data, object, messages );
@@ -196,8 +196,8 @@ na_ifactory_provider_read_item( const NAIFactoryProvider *reader, void *reader_d
}
/**
* na_ifactory_provider_write_item:
* @writer: the instance which implements this #NAIFactoryProvider interface.
* @writer_data: instance data.
* @object: the #FMAIFactoryObject derived object to be serialized.
* @messages: a pointer to a #GSList list of strings; the implementation
@@ -211,12 +211,12 @@ na_ifactory_provider_read_item( const NAIFactoryProvider *reader, void *reader_d
* Since: 2.30
*/
guint
-na_ifactory_provider_write_item( const NAIFactoryProvider *writer, void *writer_data, FMAIFactoryObject
*object, GSList **messages )
+fma_ifactory_provider_write_item( const FMAIFactoryProvider *writer, void *writer_data, FMAIFactoryObject
*object, GSList **messages )
{
- static const gchar *thisfn = "na_ifactory_provider_write_item";
+ static const gchar *thisfn = "fma_ifactory_provider_write_item";
guint code;
- g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( writer ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
+ g_return_val_if_fail( FMA_IS_IFACTORY_PROVIDER( writer ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
g_return_val_if_fail( FMA_IS_IFACTORY_OBJECT( object ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
g_debug( "%s: writer=%p, writer_data=%p, object=%p (%s)",
@@ -236,40 +236,40 @@ na_ifactory_provider_write_item( const NAIFactoryProvider *writer, void *writer_
}
static void
-v_factory_provider_read_start( const NAIFactoryProvider *reader, void *reader_data, FMAIFactoryObject
*serializable, GSList **messages )
+v_factory_provider_read_start( const FMAIFactoryProvider *reader, void *reader_data, FMAIFactoryObject
*serializable, GSList **messages )
{
- if( NA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_start ){
- NA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_start( reader, reader_data, serializable,
messages );
+ if( FMA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_start ){
+ FMA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_start( reader, reader_data, serializable,
messages );
}
}
static void
-v_factory_provider_read_done( const NAIFactoryProvider *reader, void *reader_data, FMAIFactoryObject
*serializable, GSList **messages )
+v_factory_provider_read_done( const FMAIFactoryProvider *reader, void *reader_data, FMAIFactoryObject
*serializable, GSList **messages )
{
- if( NA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_done ){
- NA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_done( reader, reader_data, serializable,
messages );
+ if( FMA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_done ){
+ FMA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_done( reader, reader_data, serializable,
messages );
}
}
static guint
-v_factory_provider_write_start( const NAIFactoryProvider *writer, void *writer_data, FMAIFactoryObject
*serializable, GSList **messages )
+v_factory_provider_write_start( const FMAIFactoryProvider *writer, void *writer_data, FMAIFactoryObject
*serializable, GSList **messages )
{
guint code = NA_IIO_PROVIDER_CODE_OK;
- if( NA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_start ){
- code = NA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_start( writer, writer_data,
serializable, messages );
+ if( FMA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_start ){
+ code = FMA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_start( writer, writer_data,
serializable, messages );
}
return( code );
}
static guint
-v_factory_provider_write_done( const NAIFactoryProvider *writer, void *writer_data, FMAIFactoryObject
*serializable, GSList **messages )
+v_factory_provider_write_done( const FMAIFactoryProvider *writer, void *writer_data, FMAIFactoryObject
*serializable, GSList **messages )
{
guint code = NA_IIO_PROVIDER_CODE_OK;
- if( NA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_done ){
- code = NA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_done( writer, writer_data,
serializable, messages );
+ if( FMA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_done ){
+ code = FMA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_done( writer, writer_data,
serializable, messages );
}
return( code );
@@ -141,14 +141,14 @@ interface_base_finalize( NAIFactoryProviderInterface *klass )
}
/**
- * na_ifactory_provider_read_item:
- * @reader: the instance which implements this #NAIFactoryProvider interface.
+ * fma_ifactory_provider_read_item:
+ * @reader: the instance which implements this #FMAIFactoryProvider interface.
* @reader_data: instance data which will be provided back to the interface
* methods
@@ -196,8 +196,8 @@ na_ifactory_provider_read_item( const NAIFactoryProvider *reader, void *reader_d
}
/**
- * na_ifactory_provider_write_item:
- * @writer: the instance which implements this #NAIFactoryProvider interface.
+ * fma_ifactory_provider_write_item:
+ * @writer: the instance which implements this #FMAIFactoryProvider interface.
* @writer_data: instance data.
* @object: the #FMAIFactoryObject derived object to be serialized.
diff --git a/src/core/na-factory-object.c b/src/core/na-factory-object.c
index dc917f8..07598ee 100644
--- a/src/core/na-factory-object.c
+++ b/src/core/na-factory-object.c
@@ -39,7 +39,7 @@
#include <api/fma-data-boxed.h>
#include <api/fma-data-types.h>
#include <api/na-iio-provider.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include <api/na-object-api.h>
#include "na-factory-object.h"
@@ -58,7 +58,7 @@ enum {
*/
typedef struct {
FMAIFactoryObject *object;
- NAIFactoryProvider *reader;
+ FMAIFactoryProvider *reader;
void *reader_data;
GSList **messages;
}
@@ -67,7 +67,7 @@ typedef struct {
/* while iterating on write item
*/
typedef struct {
- NAIFactoryProvider *writer;
+ FMAIFactoryProvider *writer;
void *writer_data;
GSList **messages;
guint code;
@@ -102,10 +102,10 @@ static FMADataGroup *v_get_groups( const FMAIFactoryObject *object );
static void v_copy( FMAIFactoryObject *target, const FMAIFactoryObject *source );
static gboolean v_are_equal( const FMAIFactoryObject *a, const FMAIFactoryObject *b );
static gboolean v_is_valid( const FMAIFactoryObject *object );
-static void v_read_start( FMAIFactoryObject *serializable, const NAIFactoryProvider *reader, void
*reader_data, GSList **messages );
-static void v_read_done( FMAIFactoryObject *serializable, const NAIFactoryProvider *reader, void
*reader_data, GSList **messages );
-static guint v_write_start( FMAIFactoryObject *serializable, const NAIFactoryProvider *reader, void
*reader_data, GSList **messages );
-static guint v_write_done( FMAIFactoryObject *serializable, const NAIFactoryProvider *reader, void
*reader_data, GSList **messages );
+static void v_read_start( FMAIFactoryObject *serializable, const FMAIFactoryProvider *reader, void
*reader_data, GSList **messages );
+static void v_read_done( FMAIFactoryObject *serializable, const FMAIFactoryProvider *reader, void
*reader_data, GSList **messages );
+static guint v_write_start( FMAIFactoryObject *serializable, const FMAIFactoryProvider *reader, void
*reader_data, GSList **messages );
+static guint v_write_done( FMAIFactoryObject *serializable, const FMAIFactoryProvider *reader, void
*reader_data, GSList **messages );
static void attach_boxed_to_object( FMAIFactoryObject *object, FMADataBoxed *boxed );
static void free_data_boxed_list( FMAIFactoryObject *object );
@@ -588,7 +588,7 @@ na_factory_object_finalize( FMAIFactoryObject *object )
/*
* na_factory_object_read_item:
* @object: this #FMAIFactoryObject instance.
* @reader: the #NAIFactoryProvider which is at the origin of this read.
* @reader_data: reader data.
* @messages: a pointer to a #GSList list of strings; the implementation
* may append messages to this list, but shouldn't reinitialize it.
@@ -596,12 +596,12 @@ na_factory_object_finalize( FMAIFactoryObject *object )
* Unserializes the object.
*/
void
-na_factory_object_read_item( FMAIFactoryObject *object, const NAIFactoryProvider *reader, void *reader_data,
GSList **messages )
+na_factory_object_read_item( FMAIFactoryObject *object, const FMAIFactoryProvider *reader, void
*reader_data, GSList **messages )
{
static const gchar *thisfn = "na_factory_object_read_item";
g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
- g_return_if_fail( NA_IS_IFACTORY_PROVIDER( reader ));
+ g_return_if_fail( FMA_IS_IFACTORY_PROVIDER( reader ));
FMADataGroup *groups = v_get_groups( object );
@@ -610,7 +610,7 @@ na_factory_object_read_item( FMAIFactoryObject *object, const NAIFactoryProvider
NafoReadIter *iter = g_new0( NafoReadIter, 1 );
iter->object = object;
- iter->reader = ( NAIFactoryProvider * ) reader;
+ iter->reader = ( FMAIFactoryProvider * ) reader;
iter->reader_data = reader_data;
iter->messages = messages;
@@ -653,7 +653,7 @@ read_data_iter( FMADataDef *def, NafoReadIter *iter )
/*
* na_factory_object_write_item:
* @object: this #FMAIFactoryObject instance.
* @writer: the #NAIFactoryProvider which is at the origin of this write.
* @writer_data: writer data.
* @messages: a pointer to a #GSList list of strings; the implementation
* may append messages to this list, but shouldn't reinitialize it.
@@ -663,7 +663,7 @@ read_data_iter( FMADataDef *def, NafoReadIter *iter )
* Returns: a NAIIOProvider operation return code.
*/
guint
-na_factory_object_write_item( FMAIFactoryObject *object, const NAIFactoryProvider *writer, void
*writer_data, GSList **messages )
+na_factory_object_write_item( FMAIFactoryObject *object, const FMAIFactoryProvider *writer, void
*writer_data, GSList **messages )
{
static const gchar *thisfn = "na_factory_object_write_item";
guint code;
@@ -671,7 +671,7 @@ na_factory_object_write_item( FMAIFactoryObject *object, const NAIFactoryProvide
gchar *msg;
g_return_val_if_fail( FMA_IS_IFACTORY_OBJECT( object ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
- g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( writer ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
+ g_return_val_if_fail( FMA_IS_IFACTORY_PROVIDER( writer ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
code = NA_IIO_PROVIDER_CODE_PROGRAM_ERROR;
@@ -690,7 +690,7 @@ na_factory_object_write_item( FMAIFactoryObject *object, const NAIFactoryProvide
if( code == NA_IIO_PROVIDER_CODE_OK ){
NafoWriteIter *iter = g_new0( NafoWriteIter, 1 );
- iter->writer = ( NAIFactoryProvider * ) writer;
+ iter->writer = ( FMAIFactoryProvider * ) writer;
iter->writer_data = writer_data;
iter->messages = messages;
iter->code = code;
@@ -900,7 +900,7 @@ v_is_valid( const FMAIFactoryObject *object )
}
static void
-v_read_start( FMAIFactoryObject *serializable, const NAIFactoryProvider *reader, void *reader_data, GSList
**messages )
+v_read_start( FMAIFactoryObject *serializable, const FMAIFactoryProvider *reader, void *reader_data, GSList
**messages )
{
if( FMA_IFACTORY_OBJECT_GET_INTERFACE( serializable )->read_start ){
FMA_IFACTORY_OBJECT_GET_INTERFACE( serializable )->read_start( serializable, reader,
reader_data, messages );
@@ -908,7 +908,7 @@ v_read_start( FMAIFactoryObject *serializable, const NAIFactoryProvider *reader,
}
static void
-v_read_done( FMAIFactoryObject *serializable, const NAIFactoryProvider *reader, void *reader_data, GSList
**messages )
+v_read_done( FMAIFactoryObject *serializable, const FMAIFactoryProvider *reader, void *reader_data, GSList
**messages )
{
if( FMA_IFACTORY_OBJECT_GET_INTERFACE( serializable )->read_done ){
FMA_IFACTORY_OBJECT_GET_INTERFACE( serializable )->read_done( serializable, reader,
reader_data, messages );
@@ -916,7 +916,7 @@ v_read_done( FMAIFactoryObject *serializable, const NAIFactoryProvider *reader,
}
static guint
-v_write_start( FMAIFactoryObject *serializable, const NAIFactoryProvider *writer, void *writer_data, GSList
**messages )
+v_write_start( FMAIFactoryObject *serializable, const FMAIFactoryProvider *writer, void *writer_data, GSList
**messages )
{
guint code = NA_IIO_PROVIDER_CODE_OK;
@@ -928,7 +928,7 @@ v_write_start( FMAIFactoryObject *serializable, const NAIFactoryProvider *writer
}
static guint
-v_write_done( FMAIFactoryObject *serializable, const NAIFactoryProvider *writer, void *writer_data, GSList
**messages )
+v_write_done( FMAIFactoryObject *serializable, const FMAIFactoryProvider *writer, void *writer_data, GSList
**messages )
{
guint code = NA_IIO_PROVIDER_CODE_OK;
@@ -588,7 +588,7 @@ na_factory_object_finalize( FMAIFactoryObject *object )
* na_factory_object_read_item:
* @object: this #FMAIFactoryObject instance.
- * @reader: the #NAIFactoryProvider which is at the origin of this read.
+ * @reader: the #FMAIFactoryProvider which is at the origin of this read.
* @reader_data: reader data.
* @messages: a pointer to a #GSList list of strings; the implementation
@@ -653,7 +653,7 @@ read_data_iter( FMADataDef *def, NafoReadIter *iter )
* na_factory_object_write_item:
* @object: this #FMAIFactoryObject instance.
- * @writer: the #NAIFactoryProvider which is at the origin of this write.
+ * @writer: the #FMAIFactoryProvider which is at the origin of this write.
* @writer_data: writer data.
* @messages: a pointer to a #GSList list of strings; the implementation
diff --git a/src/core/na-factory-provider.c b/src/core/na-factory-provider.c
index 213874b..f0ff364 100644
--- a/src/core/na-factory-provider.c
+++ b/src/core/na-factory-provider.c
@@ -37,7 +37,7 @@
/*
* na_factory_provider_read_data:
* @reader: the instance which implements this #NAIFactoryProvider interface.
* @reader_data: instance data.
* @object: the #NAIFactoryobject being unserialized.
* @def: a #FMADataDef structure which identifies the data to be unserialized.
@@ -49,19 +49,19 @@
* Returns: a new #FMADataBoxed object which contains the data.
*/
FMADataBoxed *
-na_factory_provider_read_data( const NAIFactoryProvider *reader, void *reader_data,
+na_factory_provider_read_data( const FMAIFactoryProvider *reader, void *reader_data,
const FMAIFactoryObject *object, const
FMADataDef *def,
GSList **messages )
{
FMADataBoxed *boxed;
- g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( reader ), NULL );
+ g_return_val_if_fail( FMA_IS_IFACTORY_PROVIDER( reader ), NULL );
g_return_val_if_fail( FMA_IS_IFACTORY_OBJECT( object ), NULL );
boxed = NULL;
- if( NA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_data ){
- boxed = NA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_data( reader, reader_data, object,
def, messages );
+ if( FMA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_data ){
+ boxed = FMA_IFACTORY_PROVIDER_GET_INTERFACE( reader )->read_data( reader, reader_data,
object, def, messages );
}
return( boxed );
@@ -69,7 +69,7 @@ na_factory_provider_read_data( const NAIFactoryProvider *reader, void *reader_da
/*
* na_factory_provider_write_data:
* @writer: the instance which implements this #NAIFactoryProvider interface.
* @writer_data: instance data.
* @object: the #NAIFactoryobject being serialized.
* @boxed: the #FMADataBoxed object which is to be serialized.
@@ -79,19 +79,19 @@ na_factory_provider_read_data( const NAIFactoryProvider *reader, void *reader_da
* Returns: a NAIIOProvider operation return code.
*/
guint
-na_factory_provider_write_data( const NAIFactoryProvider *writer, void *writer_data,
+na_factory_provider_write_data( const FMAIFactoryProvider *writer, void *writer_data,
const FMAIFactoryObject *object, const
FMADataBoxed *boxed,
GSList **messages )
{
guint code;
- g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( writer ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
+ g_return_val_if_fail( FMA_IS_IFACTORY_PROVIDER( writer ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
g_return_val_if_fail( FMA_IS_IFACTORY_OBJECT( object ), NA_IIO_PROVIDER_CODE_PROGRAM_ERROR );
code = NA_IIO_PROVIDER_CODE_NOT_WILLING_TO_RUN;
- if( NA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_data ){
- code = NA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_data( writer, writer_data, object,
boxed, messages );
+ if( FMA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_data ){
+ code = FMA_IFACTORY_PROVIDER_GET_INTERFACE( writer )->write_data( writer, writer_data,
object, boxed, messages );
}
return( code );
@@ -37,7 +37,7 @@
/*
* na_factory_provider_read_data:
- * @reader: the instance which implements this #NAIFactoryProvider interface.
+ * @reader: the instance which implements this #FMAIFactoryProvider interface.
* @reader_data: instance data.
* @object: the #NAIFactoryobject being unserialized.
@@ -69,7 +69,7 @@ na_factory_provider_read_data( const NAIFactoryProvider *reader, void *reader_da
/*
* na_factory_provider_write_data:
- * @writer: the instance which implements this #NAIFactoryProvider interface.
+ * @writer: the instance which implements this #FMAIFactoryProvider interface.
* @writer_data: instance data.
* @object: the #NAIFactoryobject being serialized.
diff --git a/src/core/na-factory-provider.h b/src/core/na-factory-provider.h
index a025900..c4ec536 100644
--- a/src/core/na-factory-provider.h
+++ b/src/core/na-factory-provider.h
@@ -30,23 +30,23 @@
#ifndef __CORE_FMA_FACTORY_PROVIDER_H__
#define __CORE_FMA_FACTORY_PROVIDER_H__
/* @title: NAIFactoryProvider
* @short_description: The #NAIFactoryProvider Internal Functions
* @include: core/na-factory-provider.h
*
* Declare the function only accessed from core library (not published as API).
*/
#include <api/fma-data-boxed.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
G_BEGIN_DECLS
-FMADataBoxed *na_factory_provider_read_data ( const NAIFactoryProvider *reader, void *reader_data,
+FMADataBoxed *na_factory_provider_read_data ( const FMAIFactoryProvider *reader, void *reader_data,
const FMAIFactoryObject *object,
const FMADataDef *def,
GSList **messages );
-guint na_factory_provider_write_data( const NAIFactoryProvider *writer, void *writer_data,
+guint na_factory_provider_write_data( const FMAIFactoryProvider *writer, void *writer_data,
const FMAIFactoryObject *object,
const FMADataBoxed *boxed,
GSList **messages );
@@ -30,23 +30,23 @@
#ifndef __CORE_FMA_FACTORY_PROVIDER_H__
#define __CORE_FMA_FACTORY_PROVIDER_H__
-/* @title: NAIFactoryProvider
- * @short_description: The #NAIFactoryProvider Internal Functions
+/* @title: FMAIFactoryProvider
+ * @short_description: The #FMAIFactoryProvider Internal Functions
* @include: core/na-factory-provider.h
*
diff --git a/src/io-xml/naxml-reader.c b/src/io-xml/naxml-reader.c
index 3ae4bc2..404d021 100644
--- a/src/io-xml/naxml-reader.c
+++ b/src/io-xml/naxml-reader.c
@@ -38,7 +38,7 @@
#include <api/fma-core-utils.h>
#include <api/fma-gconf-utils.h>
#include <api/fma-data-types.h>
-#include <api/na-ifactory-provider.h>
+#include <api/fma-ifactory-provider.h>
#include <api/na-object-api.h>
#include <io-gconf/nagp-keys.h>
@@ -525,7 +525,7 @@ iter_on_list_children( NAXMLReader *reader, xmlNode *list )
/* each occurrence should correspond to an elementary data
* we run first to determine the type, and allocate the object
* we then rely on NAIFactoryProvider to actually read the data
*/
for( iter = list->children ; iter && code == IMPORTER_CODE_OK ; iter = iter->next ){
@@ -585,8 +585,8 @@ iter_on_list_children( NAXMLReader *reader, xmlNode *list )
na_object_set_id( reader->private->parms->imported, reader->private->item_id );
- na_ifactory_provider_read_item(
- NA_IFACTORY_PROVIDER( reader->private->importer ),
+ fma_ifactory_provider_read_item(
+ FMA_IFACTORY_PROVIDER( reader->private->importer ),
reader,
FMA_IFACTORY_OBJECT( reader->private->parms->imported ),
&reader->private->parms->messages );
@@ -596,11 +596,11 @@ iter_on_list_children( NAXMLReader *reader, xmlNode *list )
}
void
-naxml_reader_read_start( const NAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, GSList **messages )
+naxml_reader_read_start( const FMAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, GSList **messages )
{
static const gchar *thisfn = "naxml_reader_read_start";
- g_return_if_fail( NA_IS_IFACTORY_PROVIDER( provider ));
+ g_return_if_fail( FMA_IS_IFACTORY_PROVIDER( provider ));
g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
g_debug( "%s: provider=%p, reader_data=%p, object=%p (%s), messages=%p",
@@ -630,13 +630,13 @@ read_start_profile_attach_profile( NAXMLReader *reader, NAObjectProfile *profile
* versions). So do not remove dealt-with nodes here
*/
FMADataBoxed *
-naxml_reader_read_data( const NAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, const FMADataDef *def, GSList **messages )
+naxml_reader_read_data( const FMAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, const FMADataDef *def, GSList **messages )
{
static const gchar *thisfn = "naxml_reader_read_data";
xmlNode *parent_node;
GList *ielt;
- g_return_val_if_fail( NA_IS_IFACTORY_PROVIDER( provider ), NULL );
+ g_return_val_if_fail( FMA_IS_IFACTORY_PROVIDER( provider ), NULL );
g_return_val_if_fail( FMA_IS_IFACTORY_OBJECT( object ), NULL );
g_debug( "%s: reader_data=%p, object=%p (%s), data=%s",
@@ -757,11 +757,11 @@ read_data_boxed_from_node( NAXMLReader *reader, xmlChar *path, xmlNode *parent,
* all serializable data of the object has been read
*/
void
-naxml_reader_read_done( const NAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, GSList **messages )
+naxml_reader_read_done( const FMAIFactoryProvider *provider, void *reader_data, const FMAIFactoryObject
*object, GSList **messages )
{
static const gchar *thisfn = "naxml_reader_read_done";
- g_return_if_fail( NA_IS_IFACTORY_PROVIDER( provider ));
+ g_return_if_fail( FMA_IS_IFACTORY_PROVIDER( provider ));
g_return_if_fail( FMA_IS_IFACTORY_OBJECT( object ));
g_debug( "%s: provider=%p, reader_data=%p, object=%p (%s), messages=%p",
@@ -909,8 +909,8 @@ read_done_action_load_profile( NAXMLReader *reader, const gchar *profile_id )
na_object_set_id( profile, profile_id );
- na_ifactory_provider_read_item(
- NA_IFACTORY_PROVIDER( reader->private->importer ),
+ fma_ifactory_provider_read_item(
+ FMA_IFACTORY_PROVIDER( reader->private->importer ),
reader,
FMA_IFACTORY_OBJECT( profile ),
&reader->private->parms->messages );
@@ -525,7 +525,7 @@ iter_on_list_children( NAXMLReader *reader, xmlNode *list )
/* each occurrence should correspond to an elementary data
* we run first to determine the type, and allocate the object
- * we then rely on NAIFactoryProvider to actually read the data
+ * we then rely on FMAIFactoryProvider to actually read the data
*/
for( iter = list->children ; iter && code == IMPORTER_CODE_OK ; iter = iter->next ){